==> central-repository-3.60.0.zip: java/lang/IllegalStateException.java <==
package java.lang;

import ej.annotation.Nullable;

/**
 * Signals that a method has been invoked at an illegal or inappropriate time. In other words, the
 * Java environment or Java application is not in an appropriate state for the requested operation.
 */
public class IllegalStateException extends RuntimeException {
	/**
	 * Constructs an IllegalStateException with no detail message. A detail message is a String that
	 * describes this particular exception.
	 */
	public IllegalStateException() {
		throw new RuntimeException();
	}

	/**
	 * Constructs an IllegalStateException with the specified detail message. A detail message is a
	 * String that describes this particular exception.
	 *
	 * @param s
	 *        the String that contains a detailed message
	 */
	public IllegalStateException(String s) {
		throw new RuntimeException();
	}

	/**
	 * Constructs a new exception with the specified detail message and cause.
	 *
	 * <p>
	 * Note that the detail message associated with <code>cause</code> is <i>not</i> automatically
	 * incorporated in this exception's detail message.
	 *
	 * @param message
	 *        the detail message (which is saved for later retrieval by the
	 *        {@link Throwable#getMessage()} method).
	 * @param cause
	 *        the cause (which is saved for later retrieval by the {@link Throwable#getCause()} method).
	 *        (A <tt>null</tt> value is permitted, and indicates that the cause is nonexistent or
	 *        unknown.)
	 */
	public IllegalStateException(String message, @Nullable Throwable cause) {
		throw new RuntimeException();
	}

	/**
	 * Constructs a new exception with the specified cause and a detail message of
	 * <tt>(cause==null ? null : cause.toString())</tt> (which typically contains the class and detail
	 * message of <tt>cause</tt>). This constructor is useful for exceptions that are little more than
	 * wrappers for other throwables.
	 *
	 * @param cause
	 *        the cause (which is saved for later retrieval by the {@link Throwable#getCause()} method).
	 *        (A <tt>null</tt> value is permitted, and indicates that the cause is nonexistent or
	 *        unknown.)
	 */
	public IllegalStateException(@Nullable Throwable cause) {
		throw new RuntimeException();
	}

}

==> central-repository-3.62.0.zip: java/lang/IllegalStateException.java <==
package java.lang;

import ej.annotation.Nullable;

/**
 * Signals that a method has been invoked at an illegal or inappropriate time. In other words, the
 * Java environment or Java application is not in an appropriate state for the requested operation.
 */
public class IllegalStateException extends RuntimeException {
	/**
	 * Constructs an IllegalStateException with no detail message. A detail message is a String that
	 * describes this particular exception.
	 */
	public IllegalStateException() {
		throw new RuntimeException();
	}

	/**
	 * Constructs an IllegalStateException with the specified detail message. A detail message is a
	 * String that describes this particular exception.
	 *
	 * @param s
	 *        the String that contains a detailed message
	 */
	public IllegalStateException(String s) {
		throw new RuntimeException();
	}

	/**
	 * Constructs a new exception with the specified detail message and cause.
	 *
	 * <p>
	 * Note that the detail message associated with <code>cause</code> is <i>not</i> automatically
	 * incorporated in this exception's detail message.
	 *
	 * @param message
	 *        the detail message (which is saved for later retrieval by the
	 *        {@link Throwable#getMessage()} method).
	 * @param cause
	 *        the cause (which is saved for later retrieval by the {@link Throwable#getCause()} method).
	 *        (A <code>null</code> value is permitted, and indicates that the cause is nonexistent or
	 *        unknown.)
	 */
	public IllegalStateException(String message, @Nullable Throwable cause) {
		throw new RuntimeException();
	}

	/**
	 * Constructs a new exception with the specified cause and a detail message of
	 * <code>(cause==null ? null : cause.toString())</code> (which typically contains the class and detail
	 * message of <code>cause</code>). This constructor is useful for exceptions that are little more than
	 * wrappers for other throwables.
	 *
	 * @param cause
	 *        the cause (which is saved for later retrieval by the {@link Throwable#getCause()} method).
	 *        (A <code>null</code> value is permitted, and indicates that the cause is nonexistent or
	 *        unknown.)
	 */
	public IllegalStateException(@Nullable Throwable cause) {
		throw new RuntimeException();
	}

}
